##############################################################################
# IBM Cloud Provider
##############################################################################
provider ibm {
  ibmcloud_api_key = var.ibmcloud_apikey
  region           = var.ibm_region
  generation       = var.generation
}

##############################################################################
# Data blocks
##############################################################################
data ibm_resource_group group {
  name = var.resource_group
}

data ibm_is_vpc vpc {
  name = var.vpc_name
}

data ibm_is_subnet subnet_az1 {
  identifier = var.az1_subnet
}

data ibm_is_subnet subnet_az3 {
  identifier = var.az3_subnet
}
##############################################################################
# Kube cluster (with default worker pool)
##############################################################################
resource ibm_container_vpc_cluster cluster {
  lifecycle {
    ignore_changes = [
      zones
    ]
  }

  name                            = "ev-testt"
  vpc_id                          = data.ibm_is_vpc.vpc.id
  resource_group_id               = data.ibm_resource_group.group.id
  flavor                          = "bx2.8x32"
  worker_count                    = 2
  kube_version                    = "1.17.9"
  disable_public_service_endpoint = true

  zones {
    subnet_id = data.ibm_is_subnet.subnet_az1.id
    name      = data.ibm_is_subnet.subnet_az1.zone
  }

  zones {
    subnet_id = data.ibm_is_subnet.subnet_az3.id
    name      = data.ibm_is_subnet.subnet_az3.zone
  }
}
##############################################################################
# + Additional worker pool
##############################################################################
resource ibm_container_vpc_worker_pool additional {
  cluster           = ibm_container_vpc_cluster.cluster.id
  worker_pool_name  = "additional-wp"
  flavor            = "bx2.8x32"
  vpc_id            = data.ibm_is_vpc.vpc.id
  resource_group_id = data.ibm_resource_group.group.id
  worker_count      = 2

  zones {
    subnet_id = data.ibm_is_subnet.subnet_az1.id
    name      = data.ibm_is_subnet.subnet_az1.zone
  }

  zones {
    subnet_id = data.ibm_is_subnet.subnet_az3.id
    name      = data.ibm_is_subnet.subnet_az3.zone
  }
}
##############################################################################
# Delete default worker pool
##############################################################################
resource null_resource delete_default_wp {
  provisioner "local-exec" {
    environment = {
      API_KEY        = var.ibmcloud_apikey
      REGION         = var.ibm_region
      RESOURCE_GROUP = var.resource_group
      CLUSTER        = ibm_container_vpc_cluster.cluster.id
    }

    command = file(format("%s/scripts/delete_default_wp.sh", path.root))
  }

  depends_on = [ibm_container_vpc_worker_pool.additional]
}
// ##############################################################################
// # + Additional worker pool
// ##############################################################################
// resource ibm_container_vpc_worker_pool additional_2 {
//   count = var.should_add_additional_2 ? 1 : 0

//   cluster           = ibm_container_vpc_cluster.cluster.id
//   worker_pool_name  = "additional-wp2"
//   flavor            = "bx2.8x32"
//   vpc_id            = data.ibm_is_vpc.vpc.id
//   resource_group_id = data.ibm_resource_group.group.id
//   worker_count      = 1

//   zones {
//     subnet_id = data.ibm_is_subnet.subnet_az1.id
//     name      = data.ibm_is_subnet.subnet_az1.zone
//   }
// }